# Changelog

# 1.0.0

- Require polliwog >= 1.0.0 and vg >= 2.

# 1.0.0b3

- Require polliwog 1.0.0b14 and vg >= 1.11.1.

# 1.0.0b2

- Require polliwog 1.0.0b13.

# 1.0.0b1

- Require polliwog 1.0.0b10.

# 1.0.0b0

Initial release of new library.

# 0.2.2

Versions of hobart prior to 1.0.0 are for a different library, used for
rendering cross sections to SVG. That library is now published as
[hobart-svg][].

[hobart-svg]: https://github.com/lace/hobart-svg
